<?php
/**
 * Plugin Name: BKninja: Social Counter Widget
 * Plugin URI: http://bkninja.com
 * Description: Displays social counters.
 * Version: 1.0
 * Author: BKninja
 * Author URI: http://bkninja.com
 *
 */
 
/**
 * Include required files
 */
function number_format_short( $n ) {
	if ($n > 0 && $n < 1000) {
		// 1 - 999
		$n_format = floor($n);
		$suffix = '';
	} else if ($n >= 1000 && $n < 1000000) {
		// 1k-999k
		$n_format = floor($n / 1000).'.'.round(($n % 1000)/100);
		$suffix = 'K+';
	} else if ($n >= 1000000 && $n < 1000000000) {
		// 1m-999m
		$n_format = floor($n / 1000000).'.'.round(($n % 1000000)/100000);
		$suffix = 'M+';
	} else if ($n >= 1000000000 && $n < 1000000000000) {
		// 1b-999b
		$n_format = floor($n / 1000000000).'.'.round(($n % 1000000000)/100000000);
		$suffix = 'B+';
	} else if ($n >= 1000000000000) {
		// 1t+
		$n_format = floor($n / 1000000000000).'.'.round(($n % 1000000000000)/1000000000000);
		$suffix = 'T+';
	}else {
	   $n_format = '';
       $suffix = '';
	}
    $fn = $n_format . $suffix;
    
	return !empty($fn) ? $fn : '';
}
 /**
 * Add function to widgets_init that'll load our widget.
 */
add_action('widgets_init','bk_register_social_counters_widget');

function bk_register_social_counters_widget() {
	register_widget('bk_social_counter');
	}

/**
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 */
class bk_social_counter extends WP_Widget {
    private $connection;

	private $consumer_key;
	private $consumer_secret;
	private $access_token;
	private $access_token_secret;	
	/**
	 * Widget setup.
	 */
	function __construct() {
		
		/* Widget settings. */
		$widget_ops = array('classname' => 'widget-social-counter','description' => __('Displays social counters', 'the-rex'));
		
		/* Create the widget. */
		parent::__construct('bk_social_counter',__('BKninja: Widget Social Counters', 'the-rex'),$widget_ops);

	}
	
	/**
	 * display the widget on the screen.
	 */	
	function widget( $args, $instance ) {
		extract( $args );
		//user settings	
        $title = apply_filters('widget_title', $instance['title'] );
        $bk_youtube_channel = isset($instance['bk_youtube_channel']) ? esc_attr($instance['bk_youtube_channel']) : '';
        $bk_youtube_api_key = isset($instance['bk_youtube_api_key']) ? esc_attr($instance['bk_youtube_api_key']) : '';
		$bk_dribbble_url = isset($instance['bk_dribbble_url']) ? esc_attr($instance['bk_dribbble_url']) : '';    
        $bk_rss_url = isset($instance['bk_rss_url']) ? esc_url($instance['bk_rss_url']) : '';
		$bk_facebook_url = isset($instance['bk_facebook_url']) ? esc_attr($instance['bk_facebook_url']) : '';
		$bk_twitter_URL = isset($instance['bk_twitter_URL']) ? esc_attr($instance['bk_twitter_URL']) : '';
		$bk_twitter_name = isset($instance['bk_twitter_name']) ? $instance['bk_twitter_name'] : '';
		$hours = 1;
		
		echo $before_widget;
		if ( $title )
			echo $before_title . esc_attr($title) . $after_title;

		//twitter
		if (isset($bk_twitter_URL)&&(strlen($bk_twitter_URL) != 0)){
			$transient__name = 'social_json_transient_twitter';
			$followers = bk_core::bk_count_social($bk_twitter_URL, 'twitter');
			if ( ! empty( $followers ) ) {
				update_option('bk_twitter_followers', $followers);
                update_option('bk_twitter_link', esc_url($bk_twitter_URL));
			}else{
				update_option('bk_twitter_link', esc_url($bk_twitter_URL));
			}
            set_transient( $transient__name, $followers, 60 * 60 * $hours );
		}
		//facebook
		if (isset($bk_facebook_url)&&(strlen($bk_facebook_url) != 0)){

			$transient__name = 'social_json_transient_facebook';
            $cache           = get_transient( $transient__name );
            if ( $cache === false || $cache == '' ) {
				$followers = bk_core::bk_count_social($bk_facebook_url, 'facebook');
				if ( ! empty( $followers ) ) {
					update_option('bk_facebook_cache_time', time() + 600);
					update_option('bk_facebook_followers', $followers);
					update_option('bk_facebook_link', esc_url($bk_facebook_url));
				}
				set_transient( $transient__name, $followers, 60 * 60 * $hours );
			}

		}

		
		//dribbble
		if (isset($bk_dribbble_url)&&(strlen($bk_dribbble_url) != 0)){
			$followers_count = bk_core::bk_count_social($bk_dribbble_url.'/about', 'dribbble');
			if ( ! empty( $followers_count ) ) {
				update_option('bk_dribbble_followers', $followers_count );
			}                    
		}
        // youtube
        if(isset($bk_youtube_channel)&&(strlen($bk_youtube_channel) != 0)){
        	$transient__name = 'social_json_transient_youtube';
            if($bk_youtube_api_key != ''):
                $followers = bk_core::bk_count_social($bk_youtube_channel, 'youtube', $bk_youtube_api_key);
            else:
                $followers = 0;
            endif;
            if ( ! empty( $followers ) ) {
                update_option('bk_youtube_followers', $followers);
                update_option('bk_youtube_link', $bk_youtube_channe);
			}
            set_transient( $transient__name, $followers, 60 * 60 * $hours );
        }
		?>
		<div class="wrap clearfix">
			<ul class="clearfix">
											
				<?php if (isset($bk_twitter_URL)&&(strlen($bk_twitter_URL) != 0)){ ?>
					<li class="twitter clear-fix">
                        <a target="_blank" href="<?php echo esc_attr($bk_twitter_URL); ?>">
    						<div class="social-icon"><i class="fa fa-twitter"></i></div>
    						<div class="data">
    							<div class="counter"><?php if(!empty($bk_twitter_name)): echo ''.$bk_twitter_name; endif; ?></div>
    							<div class="text"><?php _e('Followers', 'the-rex');?></div>
    						</div>
                        </a>
					</li> <!-- /twitter -->
				<?php } ?>
				
				<?php if (isset($bk_facebook_url) && (strlen($bk_facebook_url) != 0)){ ?>
					<li class="facebook clear-fix">
                        <a target="_blank" href="<?php echo get_option('bk_facebook_link'); ?>">
    						<div class="social-icon"><i class="fa fa-facebook"></i></div>
    						<div class="data">				
    							<div class="counter"><?php echo number_format_short(get_option('bk_facebook_followers')); ?></div>
    							<div class="text"><?php _e('Likes', 'the-rex');?></div>				
    						</div>
                        </a>
					</li><!-- /facebook -->
				<?php } ?>
                
				<?php if (isset($bk_dribbble_url)&&(strlen($bk_dribbble_url) != 0)){ ?>
					<li class="dribbble clear-fix">
                        <a target="_blank" href="<?php echo esc_attr($bk_dribbble_url); ?>">
    						<div class="social-icon"><i class="fa fa-dribbble"></i></div>
    						<div class="data">
    							<div class="counter"><?php echo number_format_short(get_option('bk_dribbble_followers')); ?></div>
    							<div class="text"><?php _e('Followers', 'the-rex'); ?></div>		
    						</div>
                        </a>				
					</li>
				<?php } ?>
				
				<?php if (isset($bk_youtube_username)&&(strlen($bk_youtube_username) != 0)){ ?>
					<li class="youtube clear-fix">
                        <a target="_blank" href="http://www.youtube.com/user/<?php echo esc_attr($bk_youtube_username) ;?>">
					    	<div class="social-icon"><i class="fa fa-youtube"></i></div>
    						<div class="data">
    							<div class="counter"><?php echo number_format_short(get_option('bk_youtube_subscribers')); ?></div>
    							<div class="text"><?php _e('Subscribers', 'the-rex'); ?></div>		
    						</div>
                        </a>				
					</li>
				<?php }else if (isset($bk_youtube_channel)&&(strlen($bk_youtube_channel) != 0)){ ?>
					<li class="youtube clear-fix">
                        <a target="_blank" href="http://www.youtube.com/channel/<?php echo esc_attr($bk_youtube_channel) ;?>">
					    	<div class="social-icon"><i class="fa fa-youtube"></i></div>
    						<div class="data">
    							<div class="counter"><?php echo number_format_short(get_option('bk_youtube_subscribers')); ?></div>
    							<div class="text"><?php _e('Subscribers', 'the-rex'); ?></div>		
    						</div>
                        </a>				
					</li>
                <?php } ?>
                <?php if (isset($bk_rss_url)&&(strlen($bk_rss_url) != 0)){ ?>
					<li class="rss clear-fix">
                        <a target="_blank" href="<?php echo esc_url($bk_rss_url); ?>">
    						<div class="social-icon"><i class="fa fa-rss"></i></div>
    						<div class="data">
    							<div class="subscribe"><?php _e('Subscribe', 'the-rex'); ?></div>
    							<div class="text"><?php _e('RSS Feeds', 'the-rex'); ?></div>		
    						</div>	
                        </a>			
					</li>
				<?php } ?>
				
			</ul>
				
		</div><!-- /wrap -->			
		<?php 
		echo $after_widget;
	}
	
	/**
	 * update widget settings
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;		
		$instance['title'] = strip_tags($new_instance['title']); 
        $instance['bk_youtube_channel'] = $new_instance['bk_youtube_channel'];
        $instance['bk_youtube_api_key'] = $new_instance['bk_youtube_api_key'];
		$instance['bk_dribbble_url'] = $new_instance['bk_dribbble_url'];
		$instance['bk_facebook_url'] = $new_instance['bk_facebook_url'];
        $instance['bk_rss_url'] = $new_instance['bk_rss_url'];
        $instance['bk_twitter_URL'] = $new_instance['bk_twitter_URL'];
        $instance['bk_twitter_name'] = $new_instance['bk_twitter_name'];
		return $instance;
	}
	
	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	 
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array(
        	'title' => '',
            'bk_youtube_channel' => '',
            'bk_youtube_api_key' => '',
			'bk_dribbble_url' => '',
			'bk_twitter_URL' => '',
			'bk_twitter_name' => '',
			'bk_facebook_url' => '',
            'bk_rss_url' => '',
 		);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>
		<!-- Title: Text Input -->     
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><strong><?php _e('Title:', 'the-rex');?></strong></label>
            <input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr($instance['title']); ?>" class="widefat" />
		</p>
                
		<p>
			<label for="<?php echo $this->get_field_id( 'bk_facebook_url' ); ?>"><strong><?php _e('Facebook URL:', 'the-rex');?></strong></label>
			<input type="text" id="<?php echo $this->get_field_id( 'bk_facebook_url' ); ?>" name="<?php echo $this->get_field_name( 'bk_facebook_url' ); ?>" value="<?php echo esc_attr($instance['bk_facebook_url']); ?>" class="widefat" />

            <i><?php esc_attr_e('eg. https://www.facebook.com/envato','the-rex') ?></i>
		</p>

        <p>
			<label for="<?php echo $this->get_field_id( 'bk_dribbble_url' ); ?>"><strong><?php _e('Dribbble URL', 'the-rex');?></strong></label>
			<input type="text" id="<?php echo $this->get_field_id( 'bk_dribbble_url' ); ?>" name="<?php echo $this->get_field_name( 'bk_dribbble_url' ); ?>" value="<?php echo esc_attr($instance['bk_dribbble_url']); ?>" class="widefat" />
			<i><?php esc_attr_e('eg. https://dribbble.com/envato','unidark') ?></i>
        </p>
        
        <p>
			<label for="<?php echo $this->get_field_id( 'bk_youtube_channel' ); ?>"><strong><?php _e('Youtube URL', 'the-rex');?></strong></label>
			<input type="text" id="<?php echo $this->get_field_id( 'bk_youtube_channel' ); ?>" name="<?php echo $this->get_field_name( 'bk_youtube_channel' ); ?>" value="<?php echo esc_attr($instance['bk_youtube_channel']); ?>" class="widefat" />
		</p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id( 'bk_youtube_api_key' )); ?>"><strong><?php esc_html_e('Youtube API Key', 'magneto');?></strong></label>
			<input type="text" id="<?php echo esc_attr($this->get_field_id( 'bk_youtube_api_key' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'bk_youtube_api_key' )); ?>" value="<?php echo esc_attr($instance['bk_youtube_api_key']); ?>" class="widefat" />
		</p>
        
        <p>
			<label for="<?php echo $this->get_field_id( 'bk_rss_url' ); ?>"><strong><?php _e('RSS URL', 'the-rex');?></strong></label>
			<input type="text" id="<?php echo $this->get_field_id( 'bk_rss_url' ); ?>" name="<?php echo $this->get_field_name( 'bk_rss_url' ); ?>" value="<?php echo esc_url($instance['bk_rss_url']); ?>" class="widefat" />
		</p>
        
        <p>
			<label for="<?php echo $this->get_field_id( 'bk_twitter_URL' ); ?>"><strong><?php _e('Twitter URL', 'the-rex');?></strong></label>
			<input type="text" id="<?php echo $this->get_field_id( 'bk_twitter_URL' ); ?>" name="<?php echo $this->get_field_name( 'bk_twitter_URL' ); ?>" value="<?php echo esc_attr($instance['bk_twitter_URL']); ?>" class="widefat" />
			<i><?php esc_attr_e('eg. https://www.twitter.com/envato','unidark') ?></i>
        </p>

        <p>
			<label for="<?php echo $this->get_field_id( 'bk_twitter_name' ); ?>"><strong><?php _e('Name:', 'the-rex');?></strong></label>
            <input type="text" id="<?php echo $this->get_field_id( 'bk_twitter_name' ); ?>" name="<?php echo $this->get_field_name( 'bk_twitter_name' ); ?>" value="<?php echo esc_attr($instance['bk_twitter_name']); ?>" class="widefat" />
            <i><?php esc_attr_e('eg. Envato','unidark') ?></i>
		</p>



	<?php 
	}
    	function pre_validate_keys() {
    	if ( ! $this->consumer_key        ) return false;
    	if ( ! $this->consumer_secret     ) return false;
    	if ( ! $this->access_token        ) return false;
    	if ( ! $this->access_token_secret ) return false;
    
    	return true;
	}
} //end class